@@ -1,6 +1,6 @@
 /**
   FoxyProxy
-  Copyright (C) 2006-#%#% LeahScape, Inc.
+  Copyright (C) 2006-#%#% FoxyProxy, Inc.
   http://getfoxyproxy.org/
   eric.jung@yahoo.com
 
@@ -99,7 +99,7 @@ Protocol.prototype = {
           fp.broadcast(null, "foxyproxy-proxy-change");
           break;
       }
-      fp.writeSettings(); // Save to disk
+      fp.writeSettingsAsync(); // Save to disk
     }
     
     // If foxyProxyMode was specified as "this", translate that to something that fp.setMode() understands.
