@@ -69,7 +69,12 @@ var proxyService = CC["@mozilla.org/network/protocol-proxy-service;1"].getServic
 ///////////////////////////// Proxy class ///////////////////////
 function Proxy(fp) {
   this.wrappedJSObject = this;
-  this.fp = fp || CC["@leahscape.org/foxyproxy/service;1"].getService().wrappedJSObject;
+  this.fp = fp || CC["@leahscape.org/foxyproxy/service;1"].getService().
+    wrappedJSObject;
+  this.sysProxyService = CC["@mozilla.org/system-proxy-settings;1"].
+    getService(CI.nsISystemProxySettings);
+  this.iOService = CC["@mozilla.org/network/io-service;1"].
+    getService(CI.nsIIOService);
   this.matches = [];
   this.name = this.notes = "";
   this.manualconf = new ManualConf(this, this.fp);
@@ -104,6 +109,11 @@ Proxy.prototype = {
   colorString: "nmbado",
   _proxyDNS: true,
   fp: null,
+  iOService: null,
+  sysProxyService: null,
+  // Eventually, we need one object to store the PAC settings of the proxy
+  // specified in the system settings.
+  systemProxyPAC: null,
   readOnlyProperties : ["lastresort", "fp", "wrappedJSObject", "matches", /* from ManualConf */ "owner",
                         /* from AutoConf */ "timer", /* from AutoConf */  "_resolver"],
 
@@ -313,7 +323,7 @@ Proxy.prototype = {
   get autoconfMode() {
     return this._autoconfMode;
   },
-  
+
   set proxyDNS(e) {
     this._proxyDNS = e;
     this.manualconf._makeProxy();
@@ -351,21 +361,26 @@ Proxy.prototype = {
     if (this.lastresort && !e) return; // can't ever disable this guy
     this._enabled = e;
     if (this.shouldLoadPAC()) {
-      if (this._mode === "auto") {
-        if (this._autoconfMode === "pac") {
-          this.autoconf.loadPAC();
-        } else if (this._autoconfMode === "wpad") {
-          this.wpad.loadPAC();
-        }
-      }
+      this.preparePACLoading();
     } 
-    this.handleTimer();
   },
 
   get enabled() {return this._enabled;},
 
   shouldLoadPAC : function() {
-    if (this._mode == "auto" && this._enabled) {
+    let pacURI; 
+    if (this._mode === "system") {
+      // We need the try-catch block here as on Mac OS X an exception is thrown
+      // if no PACURI is available. On Unix an empty string is given back.
+      try {
+        pacURI = this.sysProxyService.PACURI;
+      } catch (e) {
+        pacURI = null;
+      }
+    }
+         
+    if ((this._mode == "auto" || (this._mode == "system" &&
+         this.sysProxyService && pacURI)) && this._enabled) {
       var m = this.fp.mode;
       return m == this.id || m == "patterns" || m == "random" ||
         m == "roundrobin";
@@ -375,29 +390,28 @@ Proxy.prototype = {
   set mode(m) {
     this._mode = m;
     if (this.shouldLoadPAC()) {
-      if (this._mode === "auto") {
-        if (this._autoconfMode === "pac") {
-          this.autoconf.loadPAC();
-        } else if (this._autoconfMode === "wpad") {
-          this.wpad.loadPAC();
-        }
+      this.preparePACLoading();
+    }
+  },
+
+  preparePACLoading: function() {
+    if (this._mode === "auto") {
+      if (this._autoconfMode === "pac") {
+        this.autoconf.loadPAC();
+      } else if (this._autoconfMode === "wpad") {
+        this.wpad.loadPAC();
       }
-    } 
-    this.handleTimer();
+      this.handleTimer();
+    } else if (this._mode === "system") {
+      if (this.systemProxyPAC === null) {
+        this.systemProxyPAC = new AutoConf(this, this.fp);
+      }
+      this.systemProxyPAC.url = this.sysProxyService.PACURI;
+      this.systemProxyPAC.loadPAC();
+    }
   },
 
   afterPropertiesSet : function() {
-    // Load PAC if required. Note that loadPAC() is synchronous and if it fails,
-    // it changes our mode to "direct" or disables us.
-    if (this.shouldLoadPAC()) {
-      if (this._mode === "auto") {
-        if (this._autoconfMode === "pac") {
-          this.autoconf.loadPAC();
-        } else if (this._autoconfMode === "wpad") {
-          this.wpad.loadPAC();
-        }
-      }
-    } 
     // Some integrity maintenance: if this is a manual proxy and
     // this.manualconf.proxy wasn't created during deserialization, disable us.
     if (this._enabled && this._mode == "manual" && !this.manualconf.proxy) {
@@ -417,15 +431,18 @@ Proxy.prototype = {
   handleTimer : function() {
     let ac;
     if (this._autoconfMode === "pac") {
-      ac = this.autoconf; 
+      ac = this.autoconf;
     } else if (this._autoconfMode === "wpad") {
       ac = this.wpad;
     } 
     // always always always cancel first before doing anything 
     if (ac) {
       ac.timer.cancel();
+    } else {
+      // We should never reach this code path.
+      return;
     }
-    if (this.shouldLoadPAC() && ac._autoReload) {
+    if (ac._autoReload) {
       ac.timer.initWithCallback(ac, ac._reloadFreqMins*60000,
         CI.nsITimer.TYPE_REPEATING_SLACK);
     }
@@ -473,7 +490,7 @@ Proxy.prototype = {
     this.matches = this.matches.filter(function(e) {return e != removeMe;});
   },
   
-  resolve : function(spec, host, mp, isWPAD) {
+  resolve : function(spec, host, mp, mode) {
     function _notifyUserOfError(spec) {
       /*this.autoconf.errorNotification &&*/
       this.fp.notifier.alert(this.fp.getMessage("foxyproxy"),
@@ -481,11 +498,15 @@ Proxy.prototype = {
       return null;
     }
     // See http://wp.netscape.com/eng/mozilla/2.0/relnotes/demo/proxy-live.html
-    if (isWPAD) {
+    if (mode === "wpad") {
       var str = mp.pacResult = this.wpad._resolver.getProxyForURI(spec, host);
-    } else {
+    } else if (mode === "pac") {
       var str = mp.pacResult = this.autoconf._resolver.getProxyForURI(spec,
         host);
+    } else {
+      // we have the system proxy settings here
+      var str = mp.pacResult = this.systemProxyPAC._resolver.
+        getProxyForURI(spec, host); 
     }
     if (str && str != "") {
       str = str.toLowerCase();
@@ -495,10 +516,12 @@ Proxy.prototype = {
       if (tokens[tokens.length-1] == "")
         tokens.length--;
       for (var i=0; i<tokens.length; i++) {
-        if (isWPAD) {
+        if (mode === "wpad") {
           var components = this.wpad.parser.exec(tokens[i]);
-        } else {
+        } else if (mode === "pac") {
           var components = this.autoconf.parser.exec(tokens[i]); 
+        } else {
+          var components = this.systemProxyPAC.parser.exec(tokens[i]);
         }
         if (!components) continue;
         var tmp = this._proxyDNS && components[1].indexOf("socks") === 0 ?
@@ -543,17 +566,87 @@ Proxy.prototype = {
     }
   },
 
+  createProxyInfo: function(aProxyString) {
+    let proxyInfo = aProxyString.slice(6).split(":");
+    if (aProxyString.indexOf("PROXY") === 0) {
+      return proxyService.newProxyInfo("http", proxyInfo[0], proxyInfo[1], 0,
+        0, null);
+    } else if (aProxyString.indexOf("SOCKS") === 0) {
+      let remoteResolve;
+      if (this._proxyDNS) {
+        remoteResolve = CI.nsIProxyInfo.TRANSPARENT_PROXY_RESOLVES_HOST;
+      } else {
+        remoteResolve = 0;
+      }
+      return proxyService.newProxyInfo("socks", proxyInfo[0], proxyInfo[1],
+        remoteResolve, 0, null); 
+    } else {
+      dump("Unknown proxy type!\n");
+      return this.direct; 
+    }
+  },
+
+  getSystemProxy: function(spec, host, mp) {
+    // If system proxy settings are not supported on the system we give
+    // "direct" back as Mozilla does.
+    if (!this.sysProxyService) {
+      return this.direct;
+    } else {
+      // We need the try-catch block here as on Mac OS X an exception is thrown
+      // if no PACURI is available. On Unix an empty string is given back.
+      let pacURI;
+      try {
+        pacURI = this.sysProxyService.PACURI;
+      } catch (e) {
+        pacURI = null;
+      }
+      if (pacURI) {
+        // The user wants to use a PAC file. Let's check what we have to do.
+        if (!this.systemProxyPAC.url || this.systemProxyPAC.url != pacURI) {
+          // This case means the user ether changed the system proxy settings
+          // from direct or manual proxy to PAC mode for the first time in the
+          // session. Or the PAC URI changes meanwhile in the system proxy
+          // settings while still having the proxy in use. In both cases we
+          // have to reload the PAC.
+          this.systemProxyPAC.url = pacURI;
+          this.systemProxyPAC.loadPAC();
+          return this.resolve(spec, host, mp, "system");
+        } else if (this.systemProxyPAC.url == pacURI) {
+          // The easiest case: We just take the already loaded PAC
+          return this.resolve(spec, host, mp, "system"); 
+        }
+        return this.direct;
+      } else {
+        let uri = this.iOService.newURI(spec, null, null);
+        let proxyString = this.sysProxyService.getProxyForURI(uri);
+        if (proxyString == "DIRECT") {
+          return this.direct;
+        } else {
+          // We have to construct a proxyInfo object out of the manual settings
+          // we got back.
+          return this.createProxyInfo(proxyString);
+        }
+      }
+    }
+  },
+
   getProxy : function(spec, host, mp) {
     switch (this._mode) {
-      case "manual":return this.manualconf.proxy;
+      case "manual": return this.manualconf.proxy;
       case "auto":
         if (this._autoconfMode === "pac") {
-          return this.resolve(spec, host, mp, false);
+          return this.resolve(spec, host, mp, "pac");
         } else {
           // WPAD
-          return this.resolve(spec, host, mp, true);
+          return this.resolve(spec, host, mp, "wpad");
         }
-      case "direct":return this.direct;
+      // TODO: We should consider using a timer to periodically re-call
+      // getSystemProxy(). But the main problem is that we could miss changes in
+      // the global blacklist as this one is considered while determining the
+      // proxy for every request. That could be especially painful for users in
+      // China or other restrictive countries, a thing we may want to avoid.
+      case "system": return this.getSystemProxy(spec, host, mp);
+      case "direct": return this.direct;
     }
   },
   
